#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.

# NOTE(rosmaita): This file implements the migration interface, but doesn't
# migrate any data.  The pike01 migration is contract-only.


def has_migrations(engine):
    """Returns true if at least one data row can be migrated."""

    return False


def migrate(engine):
    """Return the number of rows migrated."""

    return 0
